@@ -29,6 +29,8 @@ class ArticleItem(scrapy.Item):
     oss_movies = scrapy.Field()
     other_info = scrapy.Field()
     upload_oss = scrapy.Field()
+    download_video = scrapy.Field()
+    download_image = scrapy.Field()
     created_date = scrapy.Field()
 
 def get_item(response, source, block, parse=True):
